@@ -1,8 +1,4 @@
 // This file is released into Public Domain.
-extern crate gnuplot;
-
-use common::*;
-
 use gnuplot::*;
 use std::iter::repeat;
 
